@@ -2,13 +2,17 @@ author='Rocky Bernstein, Ned Batchelder, Paul Swartz, Allison Kaptur and others'
 author_email='rb@dustyfeet.com'
 entry_points = {"console_scripts": ["xpython=xpython.__main__:main"]}
 install_requires=["six", "xdis", "click"],
+py_modules = None
 short_desc = "Python cross-version byte-code interpeter"
 url='http://github.com/rocky/xpython'
 
 classifiers = [
+    "Operating System :: OS Independent",
     "Programming Language :: Python :: 2.7",
+    "Programming Language :: Python :: 3.2",
     "Programming Language :: Python :: 3.3",
     "Programming Language :: Python :: 3.4",
+    "Programming Language :: Python :: 3.5",
 ]
 import os.path as osp
 
